@@ -12,13 +12,17 @@ from .number import directquant
 class ReLU(nn.ReLU):
     def __init__(self,
                  inplace=False,
+                 input_bit_width=8,
                  acti_bit_width=8,
-                 retrain=True,
-                 quant=False):
+                 iostrict=False):
         super().__init__(inplace)
         self.acti_bit_width = acti_bit_width
+        self.acti_input_bit_width = acti_input_bit_width
+        self.iostrict = iostrict
 
     def relu_forward(self, input):
+        if self.iostrict is True:
+            input = directquant(input, self.acti_input_bit_width)
         return directquant(F.relu(input), self.acti_bit_width)
 
     def forward(self, input):
@@ -26,11 +30,19 @@ class ReLU(nn.ReLU):
 
 
 class ReLU6(nn.ReLU6):
-    def __init__(self, inplace=False, acti_bit_width=8):
+    def __init__(self,
+                 inplace=False,
+                 acti_bit_width=8,
+                 input_bit_width=8,
+                 iostrict=False):
         super().__init__(inplace)
         self.acti_bit_width = acti_bit_width
+        self.input_bit_width = input_bit_width
+        self.iostrict = iostrict
 
     def relu6_forward(self, input):
+        if self.iostrict is True:
+            input = directquant(input, self.input_bit_width)
         return directquant(F.relu6(input), self.acti_bit_width)
 
     def forward(self, input):
