@@ -15,18 +15,29 @@ class Linear(nn.Linear):
                  out_features,
                  bias=True,
                  weight_bit_width=8,
-                 bias_bit_width=16):
+                 bias_bit_width=16,
+                 input_bit_width=8,
+                 output_bit_width=12,
+                 iostrict=False):
         super().__init__(in_features, out_features, bias=bias)
         self.weight_bit_width = weight_bit_width
         self.bias_bit_width = bias_bit_width
+        self.input_bit_width = input_bit_width
+        self.output_bit_width = self.output_bit_width
+        self.iostrict = iostrict
 
     def linear_forward(self, input):
+        if self.iostrict is True:
+            input = directquant(input, self.input_bit_width)
         if self.bias is None:
             bias = None
         else:
             bias = directquant(self.bias, self.bias_bit_width)
         weight = directquant(self.weight, self.weight_bit_width)
-        return F.linear(input, weight, bias)
+        output = F.linear(input, weight, bias)
+        if self.iostrict is True:
+            output = directquant(output, self.output_bit_width)
+        return output
 
     def forward(self, input):
         return self.linear_forward(input)
